from setuptools import setup

setup(name='udi_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['udi_probability'],
      author = 'Pranjal Raj',
      author_email = 'pranjalraj0046@gmail.com',
      zip_safe=False)
